import { ref, onMounted, onUnmounted } from '@vue/composition-api';

function getQuery(min, max) {
    if (min === void 0) { min = 0; }
    if (max === void 0) { max = 0; }
    if (!min && !max) {
        throw new Error("Please specify at least one value, either 'min' or 'max'");
    }
    else if (min && !max) {
        return "only screen and (min-width: " + min + "px)";
    }
    else if (!min && max) {
        return "only screen and (max-width: " + (max - 1) + "px)";
    }
    else {
        return "only screen and (min-width: " + min + "px) and (max-width: " + (max - 1) + "px)";
    }
}

function useMedia(query, defaultState) {
    if (defaultState === void 0) { defaultState = false; }
    var mql;
    var matches = ref(defaultState);
    var updateMatchValue = function () { return (matches.value = mql.matches); };
    onMounted(function () {
        mql = window.matchMedia(query);
        mql.addListener(updateMatchValue);
        updateMatchValue();
    });
    onUnmounted(function () {
        mql.removeListener(updateMatchValue);
    });
    return matches;
}

function useMouse(el) {
    var docX = ref(0);
    var docY = ref(0);
    var elX = ref(0);
    var elY = ref(0);
    var mouseMoveHandler = function (e) {
        docX.value = e.pageX;
        docY.value = e.pageY;
        if (!el || !el.value)
            return;
        var _a = el.value.getBoundingClientRect(), left = _a.left, top = _a.top;
        var posX = left + window.pageXOffset;
        var posY = top + window.pageYOffset;
        elX.value = e.pageX - posX;
        elY.value = e.pageY - posY;
    };
    onMounted(function () {
        document.addEventListener('mousemove', mouseMoveHandler);
    });
    onUnmounted(function () {
        document.removeEventListener('mousemove', mouseMoveHandler);
    });
    return {
        docX: docX,
        docY: docY,
        elX: elX,
        elY: elY
    };
}

export { getQuery, useMedia, useMouse };
